==> haskell-skylighting-format-context-0.1.0.2-224-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-8CAcVgQD8N01elTghTiaTY
key:                  skylighting-format-context-0.1.0.2-8CAcVgQD8N01elTghTiaTY
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  cc9a15e2e1d72a790d74afaf01be0d24
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-8CAcVgQD8N01elTghTiaTY
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.2-DB3Bg6HHgy674FCTp1eWcE text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-context-0.1.0.2-244-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-DRUS6ckAZPPG2JXjiIHkvC
key:                  skylighting-format-context-0.1.0.2-DRUS6ckAZPPG2JXjiIHkvC
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  8cdb6588df3e5124071ab136a7f46e0c
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-DRUS6ckAZPPG2JXjiIHkvC
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.3-3942VFqpxT92bo8sB6TPZ4 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
